@@ -136,7 +136,7 @@ class App:
 
         except Exception as e:
             error = traceback.format_exc()
-            return self.exception_handler.handle_error(error)
+            response = self.exception_handler.handle_error(error)
 
         return response
 
